@@ -5,7 +5,7 @@ from ..utils import config_path
 
 def get_configs(cfg):
     cfg_output = {}
-    cfg = config_path("base/{cfg}.yaml")
+    cfg = config_path(f"base/{cfg}.yaml")
     with open(cfg) as f:
         cfg_output.update(yaml.load(f, Loader=yaml.FullLoader))
 
